@@ -13,6 +13,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <locale.h>
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -193,6 +194,7 @@ main (int argc, char **argv)
         bindtextdomain (GETTEXT_PACKAGE, GNOME_SETTINGS_LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
+        setlocale (LC_ALL, "");
 
         set_empty_gtk_theme (TRUE);
 
